C
C
C
      PROGRAM   J330
C
C     + + + PURPOSE + + +
C     This program calculates daytime net productivity, night
C     respiration, and total community metabolism from a series of
C     dissolved oxygen, temperature, and salinity measurements.
C     Values may be calculated for a single stream station, for the
C     difference between two stream stations, or for a lake or
C     reservoir.
C
C     The original program by Doyle W. Stephens and Marshall E. Jennings
C     (1976) was written in FORTRAN IV for the IBM operating system.
C     It was converted to FORTRAN 77 and the Office of Surface Water
C     coding conventions by Claud H. Baker, Jr. in August 1991
C
C     + + + COMMON BLOCKS + + +
      INCLUDE  'cj3301.inc'
      INCLUDE  'cj3302.inc'
      INCLUDE  'cj3304.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER I, I1, IDAY, INIGHT, IREAD, IUNITS
      INTEGER J, JJ, K, KK, IERR
      REAL DEP, DIFCL
      CHARACTER*3  TEST
      CHARACTER*22 UNITS
      CHARACTER*64 VERSN
C
C     + + + INTRINSICS + + +
      INTRINSIC  ABS, FLOAT
C
C     + + + EXTERNALS + + +
      EXTERNAL  BELLA, COND, INTERP, ODUM1, ODUM2
      EXTERNAL OXYGEN, PRNT, OPENFS
C
C     + + + INPUT FORMATS + + +
 1000 FORMAT(BN,A28,F4.0,F5.0,I2,I3,F5.2,I5,2F6.0)
 1010 FORMAT (BN,F3.1,4X,4I2,I3,A3,I2,2F6.0,I5)
 1020 FORMAT(BN,6I2)
 1030 FORMAT(BN,I2,6X,3F8.0/(2I2,4X,3F8.0))
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT(' Illegal  method selection code -- job terminated')
 2010 FORMAT(' Number of lake slices exceeds 10 -- job terminated')
 2020 FORMAT('',24X,'Oxygen Productivity Computations'//21X,
     #  'Hydrologic Applications Support Section'/30X,
     #  'U.S. Geological Survey'/29X,'Water Resources Division'//
     #  29X,'Last revised March, 1996 '//)
 2030 FORMAT(28X,'Bella - Odum Lake Analysis'//)
 2040 FORMAT (1X,A28/)
 2050 FORMAT(F8.3,' = Surface diffusion coefficient, GM O2/M3/HR',
     #  ' at 100% saturation deficit'/
     #  F8.3,' = Dispersion coefficient, square centimeters per second'
     #  /F8.3,' = Salinity, parts per thousand'/F8.2,' = Depth, feet'/
     #  4X,2I2.2,' = Time of sunrise, military time'/4X,2I2.2,
     #  ' = Time of sunset, military time'/F8.2,
     #  ' = Barometric pressure, ',A/I8,
     #  ' = Number of lake slices (maximum 10)'/
     #  F8.2,' = Depth interval for lake slices'/
     #  I8,' = number of observations (maximum 97)'/I8,
     #  ' = Print flag for interpolated data (0-no, 1-yes)')
 2060  FORMAT(/11X,'Observed data - lake slice',I3//30X,'Dissolved'/
     #  11X,'Time',2X,'Temperature',3X,'Oxygen',3X,'Salinity'/
     #  18X,'Degrees C     MG/L       PPT'/)
 2070 FORMAT(11X,2I2.2 ,2F10.2,2F11.2)
 2080 FORMAT ('','Time increments',F6.2,'and',F6.2,
     #  ' are closer than 15 minutes -- job terminated')
 2090 FORMAT('Interpolated input data -- lake slice -- ',I3,5X,
     #  'depth = ',F5.2,' meters'/)
 2100 FORMAT ('')
C
C     + + + END SPECIFICATIONS + + +
C
C     include unix version information
      INCLUDE 'versn.inc'
C
C     Assign values to the file units and call OPENFS to open the files
      IREAD = 11
      IOUT = 12
      CALL OPENFS (IREAD, IOUT, IERR)
C
C     If OPENFS returns non-zero, the input file couldn't be found
C     and the user chose to quit the program
C
      IF (IERR .NE. 0) THEN
        WRITE (*,*) 'File open error -- program ended'
        GO TO 999
      END IF
C
C     Although it is not specifically discussed in the documentation,
C     the program was written to allow multiple problems in a single
C     run. After each problem is solved and all output written, control
C     is returned unconditionally to statement 10. The only normal
C     exit from the program is via the END= directive in the first
C     read statement.
C
 10   CONTINUE
C
C     Initialize variables
C
      KK=1
      TEST2 = 1
      DO 20 I=1,7
        DO 20 J=1,97
          XNEW(I,J)=0.0
          X(I,J)=0.0
          XNEW1(I,J)=0.0
 20   CONTINUE
C
C     Read the first input record for a new problem; on end-of-file,
C     exit the program [statement 999 is program exit]
      READ(IREAD,1000,END=999)NAME1,Q,BP,IPRNT,METD,TT,
     #  NN,DELTZ,DIFCL
C
C     METD is a flag for problem selection; valid values are 1, 2, and
C     3. Check for out of range, write an error message, and exit.
      IF (METD .LT. 1 .OR. METD .GT. 3) THEN
        WRITE(IOUT,2000)
        GO TO 999
      END IF
      DV(1) = DIFCL
C
C     NN is the number of horizontal "slices" for a lake problem; the
C     maximum is 10. If that value is exceeded, write an error message
C     and exit the program.
      IF(NN.GT.10) THEN
        WRITE (IOUT,2010)
        GO TO 999
      END IF
C
C     Read the second input record
C
      READ(IREAD,1010) DEPTH,IDAY1,IDAY2,INIGH1,INIGH2,TEST1,TEST,
     #  N20,AREA,VELO,IUNITS
C
C     Variable IUNITS indicates whether depth, velocity, discharge,
C     and area are in English or metric units. Here we set the values
C     to the units needed for computation -- english for DEPTH and VELO,
C     metric for AREA and Q.
      IF (IUNITS .EQ. 0) THEN
C       sq meters = sq feet * (.3048**2),   cms = cfs * .028317
        AREA = AREA * 0.092903
        Q = Q * 0.028317
       ELSE
C       feet = meters * xx,    feet/sec = meters/sec * xx
C       note:  conversion factor corrected re CGCrawford, 07/95, kmf.
C       DEPTH = DEPTH * 3.048
C       VELO = VELO * 3.048
        DEPTH = DEPTH * 3.2808
        VELO = VELO * 3.2808
      END IF
      IF (TEST .EQ. 'YES') TEST2 = 0
      IF(METD.EQ.3) THEN
C       For lake analysis, print initial headings
        WRITE(IOUT,2020)
        WRITE(IOUT,2030)
        WRITE(IOUT,2040) NAME1
      END IF
C
C     For METD = 3, control returns to statement 30 to read observations
C     for each lake "slice".
C
 30   CONTINUE
      READ(IREAD,1030) NOBS,DIFC,SALIN,K2,(ITM1(J),ITM2(J),
     #  (X(I,J),I=2,4),J=1,NOBS)
      IF(METD.EQ.3) THEN
C
C       Set the units for listing barometric pressure according to the
C       magnitude of the value.
        IF (BP .GT. 50.) THEN
          UNITS = 'millimeters of mercury'
         ELSE
          UNITS = 'Inches of mercury'
        END IF
C
        IF (KK .EQ. 1) WRITE(IOUT,2050)DIFCL,DIFC,SALIN,DEPTH,IDAY1,
     #    IDAY2,INIGH1,INIGH2,BP,UNITS,NN,DELTZ,NOBS,IPRNT
        WRITE(IOUT,2060) KK
        DO 40 J=1,NOBS
          WRITE(IOUT,2070)ITM1(J),ITM2(J),(X(I,J),I=2,4)
 40     CONTINUE
      END IF
C
C     Convert times from hours and minutes to decimal hours
      DAYBEG = FLOAT(IDAY1) + FLOAT(IDAY2) / 60.
      DAYEND = FLOAT(INIGH1) + FLOAT(INIGH2) / 60.
      DO 50 J=1,NOBS
        X(1,J) = FLOAT(ITM1(J)) + FLOAT(ITM2(J)) / 60.
 50   CONTINUE
C
C     Check for observations less than 15 minutes apart; if found,
C     write an error message and exit.
      DO 60 K=1,NOBS-1
        IF (ABS(X(1,K+1)-X(1,K)) .LT. 0.25) THEN
          WRITE (IOUT,2080) X(1,K),X(1,K+1)
          GO TO 999
        END IF
 60   CONTINUE
      DO 70 J=2,NOBS
        IF (X(1,J) .GT. X(1,1)) THEN
          X(1,J) = X(1,J) - X(1,1)
         ELSE
          X(1,J) = 24. - X(1,1) + X(1,J)
        END IF
 70   CONTINUE
      IF (DAYBEG .GT. X(1,1)) THEN
        DAYBEG = DAYBEG - X(1,1)
       ELSE
        DAYBEG = 24. - X(1,1) + DAYBEG
      END IF
      IF (DAYEND .GT. X(1,1)) THEN
        DAYEND = DAYEND - X(1,1)
       ELSE
        DAYEND = 24. - X(1,1) + DAYEND
      END IF
      X(1,1) = 0.
      I2 = 97
      JJ = 1
C
C     If SALIN is non-zero, it is a constant value to be used for
C     all observations.
      IF (SALIN .GT. 0.0) THEN
        DO 80 J=1,NOBS
          X(4,J) = SALIN
 80     CONTINUE
      END IF
C
C     If conductivity was entered, call COND to convert it to salinity
      IF(TEST2 .EQ. 0) CALL COND (N20,NOBS,X)
C
C     If we haven't got an observation every 15 minutes, interpolate
C     15-minute values
      IF (NOBS .LT. 97) CALL INTERP(X,NOBS,XNEW)
      IF (METD .EQ. 1) THEN
        CALL ODUM1
       ELSE IF (METD .EQ. 2) THEN
        CALL ODUM2 (IREAD)
       ELSE
        DEP = DELTZ * KK
        IF(KK.EQ.1) CALL OXYGEN(I2,DIFCL,BP,METD,XNEW)
        IF(IPRNT .GT. 0) THEN
          WRITE(IOUT,2090)KK,DEP
          CALL PRNT(1)
          WRITE(IOUT,2100)
        END IF
        IF(KK .EQ. 1)  THEN
          DO 90 I=1,97
            IF(XNEW(1,I) .LE. DAYBEG) IDAY = I
            IF(XNEW(1,I) .LE. DAYEND) INIGHT = I
            XNEW(7,I) = XNEW(7,I) / 100.
 90       CONTINUE
          DO 100 I=2,I2
            I1 = I - 1
            FUNC(I) = (XNEW(7,I) + XNEW(7,I1)) / 2. - 1.0
 100      CONTINUE
          XNEW(7,1) = XNEW(7,2)
          FUNC(1) = FUNC(2)
        END IF
        DO 110 J=1,97
          XBELLA(J,KK) = XNEW(3,J)
 110    CONTINUE
        KK = KK + 1
        DV(KK) = DIFC
        IF(KK .GT. NN)THEN
          CALL BELLA (IDAY,INIGHT)
         ELSE
          GO TO 30
        END IF
      END IF
      GO TO 10
 999  STOP
      END
C
C
C
      SUBROUTINE   ODUM1
C
C     + + + PURPOSE + + +
C     Subroutine ODUM1 is called from the main program for the analysis
C     of a single station. Input data are interpolated to 15-minute
C     intervals, oxygen production is calculated, and respiration is
C     calculated, all through subroutine calls. Format and headings for
C     the program output are printed
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'cj3301.inc'
      INCLUDE 'cj3302.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER I, J, IDAY, INIGHT
      CHARACTER*22 UNITS
C
C     + + + EXTERNALS + + +
      EXTERNAL  CONS, OXYGEN, PRNT, SUMMER
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT('',24X,'Oxygen Productivity Computations'//21X,
     #  'Hydrologic Applications Support Section'/30X,
     #  'U.S. Geological Survey'/29X,'Water Resources Division'//
     #  29X,'Last revised March, 1996 '//)
 2010 FORMAT(26X,'Odum single station analysis'/)
 2020 FORMAT (2X,A28/)
 2040 FORMAT(F8.3,' = Surface diffusion coefficient, GM O2/M3/HR',
     #  ' at 100% saturation deficit'/
     #  F8.3,' = K2 (base e), per day at 20 degrees celsius',
     #  /F8.3,' = Salinity, parts per thousand'/F8.2,' = Depth, feet'/
     #  4X,2I2.2,' = Time of sunrise, military time'/4X,2I2.2,
     #  ' = Time of sunset, military time'/F8.2,
     #  ' = Barometric pressure, ',A/F8.2,
     #  ' = Average velocity, feet per second'/I8,
     #  ' = number of observations (maximum 97)'/I8,
     #  ' = Print flag for interpolated data (0-no, 1-yes)')
 2050 FORMAT(/11X,'Observed data'//30X,'Dissolved'/
     #  11X,'Time',2X,'Temperature',3X,'Oxygen',3X,'Salinity'/
     #  18X,'Degrees C     MG/L       PPT'/)
 2060 FORMAT(11X,2I2.2 ,2F10.2,2F11.2)
 2070 FORMAT(' Interpolated input data'//)
C
C     + + + END SPECIFICATIONS + + +
C
C     Find position of sunrise and sunset in xnew
C
      DO 20 I=1,I2
        IF(XNEW(1,I) .LE. DAYBEG)  IDAY = I
        IF(XNEW(1,I) .LE. DAYEND)  INIGHT = I
 20   CONTINUE
C
C     Calculate oxygen production
C
      IF (DIFC .GT. 98.) CALL CONS (BP,DEPTH,K2,VELO,XNEW,DIFC)
      CALL OXYGEN(I2,DIFC,BP,METD,XNEW)
C
C     Write heading for single station analysis
C     Computed values will be written by subroutine SUMMER
C
      WRITE (IOUT,2000)
      WRITE (IOUT,2010)
      WRITE (IOUT,2020) NAME1
C
C     Set "UNITS" to inches or millemeters depending on size of BP
      IF (BP .GT. 50.) THEN
        UNITS = 'millimeters of mercury'
       ELSE
        UNITS = 'inches of mercury'
      END IF
      WRITE (IOUT,2040) DIFC,K2,SALIN,DEPTH,IDAY1,IDAY2,INIGH1,INIGH2,
     #  BP,UNITS,VELO,NOBS,IPRNT
      WRITE (IOUT,2050)
      DO 30 J=1,NOBS
        WRITE (IOUT,2060) ITM1(J),ITM2(J),(X(I,J),I=2,4)
 30   CONTINUE
C
C     Optional listing of interpolated values
      IF(IPRNT .GT. 0)THEN
        WRITE(IOUT,2070)
        CALL PRNT(1)
      END IF
      CALL SUMMER (IDAY,INIGHT)
      RETURN
      END
C
C
C
      SUBROUTINE   COND
     I                 (N20,NOBS,
     M                  X)
C
C     + + + PURPOSE + + +
C     Subroutine COND converts conductivity (either corrected to 20
C     degrees C or uncorrected) to salinity.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER N20, NOBS
      REAL X(7,97)
C
C     + + + ARGUMENT DEFINITIONS + + +
C
C     N20    - Flag to indicate whether conductivity has been corrected
C              to 25 degrees C; 1 = corrected.
C     NOBS   - The number of rows in array X that contain input values.
C     X      - the input data array; temperature is in column
C              2 and conductivity in column 4. Conductivity values are
C              replaced with calculated salinity values in this subroutine.
C
C     + + + LOCAL VARIABLES + + +
      INTEGER I
      REAL C, T
C
C     + + + END SPECIFICATIONS + + +
C

      IF (N20 .NE. 1) THEN
C       conductivity is not temperature corrected
C       convert the data using temperature from the X array [col 2].
        DO 10 I=1,NOBS
          T = X(2,I) * 0.1
          C = X(4,I) * 0.0001
          X(4,I) = -.205 + T * (.193 - .0546 * T) + C * (10.6 + T *
     #      (.590 * T - 3.59) + C * (.607 - .0465 * C + T *
     #      (.0542 - .0515 * T)))
 10     CONTINUE
       ELSE
C       convert temperature-corrected conductivity
        DO 20 I=1,NOBS
          C = X(4,I) * 0.0001
          X(4,I) = -.0638 + C * (5.31 + C * (.4214 - .0465 * C))
 20     CONTINUE
      END IF
      RETURN
      END
C
C
C
      SUBROUTINE   ODUM2
     I                  (IREAD)
C
C     + + + PURPOSE + + +
C     Subroutine ODUM2 solves for the two-station problem, calling
C     the same subroutines used by ODUM1. Headings for both stations
C     are printed. The subroutine reads input data for the downstream
C     station; data for the upstream station was read by the main
C     program.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER IREAD
C
C     + + + ARGUMENT DEFINITIONS + + +
C
C     IREAD  - input unit from which to read data for downstream station
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'cj3301.inc'
      INCLUDE 'cj3302.inc'
      INCLUDE 'cj3303.inc'
C     + + + LOCAL VARIABLES + + +
      INTEGER I, J, IDAY, INIGHT, JJ, NN1
      REAL ADIFC, C2, TROC
      CHARACTER*22 UNITS
C
C     + + + INTRINSICS + + +
      INTRINSIC FLOAT
C
C     + + + EXTERNALS + + +
      EXTERNAL COND, CONS, INTERP, OXYGEN, PRNT, SUMMER
C
C     + + + INPUT FORMATS + + +
 1000 FORMAT(A28)
 1010 FORMAT(BN,I2,6X,2F8.0/(2I2,4X,3F8.0))
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT('',24X,'Oxygen Productivity Computations'//21X,
     #  'Hydrologic Applications Support Section'/30X,
     #  'U.S. Geological Survey'/29X,'Water Resources Division'//
     #  29X,'Last revised March, 1996 '//)
 2010 FORMAT(18X,'Odum two station analysis - upstream station'/)
 2020 FORMAT (2X,A28/)
 2040 FORMAT(F8.3,' = Surface diffusion coefficient, GM O2/M3/HR',
     #  ' at 100% saturation deficit'/
     #  F8.3,' = K2 (base e), per day at 20 degrees celsius',
     #  /F8.3,' = Salinity, parts per thousand'/F8.2,' = Depth, feet'/
     #  4X,2I2.2,' = Time of sunrise, military time'/4X,2I2.2,
     #  ' = Time of sunset, military time'/F8.2,
     #  ' = Barometric pressure, ',A/F8.2,
     #  ' = Average velocity, feet per second'/I8,
     #  ' = number of observations (maximum 97)'/I8,
     #  ' = Print flag for interpolated data (0-no, 1-yes)')
 2045 FORMAT(F8.3,' = Surface diffusion coefficient, GM O2/M3/HR',
     #  ' at 100% saturation deficit'/
     #  F8.3,' = K2 (base e), per day at 20 degrees celsius',
     #  /F8.3,' = Salinity, parts per thousand'/F8.2,' = Depth, feet'/
     #  4X,2I2.2,' = Time of sunrise, military time'/4X,2I2.2,
     #  ' = Time of sunset, military time'/F8.2,
     #  ' = Barometric pressure, ',A/F8.2,
     #  ' = Discharge, cubic meters per second'/F8.2,
     #  ' = Surface area, square meters'/F8.2,
     #  ' = Travel time, hours'/F8.2,
     #  ' = Average velocity, feet per second'/I8,
     #  ' = number of observations (maximum 97)')
 2050 FORMAT(/11X,'Observed data'//30X,'Dissolved'/
     #  11X,'Time',2X,'Temperature',3X,'Oxygen',3X,'Salinity'/
     #  18X,'Degrees C     MG/L       PPT'/)
 2060 FORMAT(11X,2I2.2 ,2F10.2,2F11.2)
 2070 FORMAT(' Interpolated input data - upstream station'//)
 2080 FORMAT('',17X,'Odum two station analysis - downstream station'/)
 2090 FORMAT(' Interpolated input data - downstream station')
C
C     + + + END SPECIFICATIONS + + +
C
C     Write headings and upstream data for two station problem
C     (Data for upstream station were read by main routine)
      WRITE(IOUT,2000)
      WRITE(IOUT,2010)
      WRITE(IOUT,2020) NAME1
      IF (DIFC .GE. 99.) CALL CONS (BP,DEPTH,K2,VELO,XNEW,DIFC)
C
C     Set "UNITS" to inches or millemeters depending on size of BP
      IF (BP .GT. 50.) THEN
        UNITS = 'millimeters of mercury'
       ELSE
        UNITS = 'inches of mercury'
      END IF
      WRITE(IOUT,2040) DIFC,K2,SALIN,DEPTH,IDAY1,IDAY2,INIGH1,INIGH2,
     #  BP,UNITS,VELO,NOBS,IPRNT
      WRITE(IOUT,2050)
      JJ = 1
      DO 20 J=1,NOBS
        WRITE(IOUT,2060) ITM1(J),ITM2(J),(X(I,J),I=2,4)
  20  CONTINUE
      DO 30 I=1,I2
        IF(XNEW(1,I) .LE. DAYBEG) IDAY = I
        IF(XNEW(1,I) .LE. DAYEND) INIGHT = I
 30   CONTINUE
      CALL OXYGEN(I2,DIFC,BP,METD,XNEW)
      IF(IPRNT .GT. 0) THEN
        WRITE(IOUT,2070)
        CALL PRNT(1)
      END IF
      ADIFC=DIFC
C
C     Now read and manipulate data for downstream station.
      READ(IREAD,1000) NAME2
      READ(IREAD,1010) NOBS,DIFC,SALIN,(ITM1(J),ITM2(J), (X(I,J),I=2,4),
     #  J=1,NOBS)
      DAYBEG = FLOAT(IDAY1) + FLOAT(IDAY2) / 60.
      DAYEND = FLOAT(INIGH1) + FLOAT(INIGH2) / 60.
      HRSUN = DAYEND - DAYBEG
      HRDARK = 24. - HRSUN
C
C     change time from hours & minutes to cumulative hours
      DO 40 J=1,NOBS
        X(1,J) = FLOAT(ITM1(J)) + FLOAT(ITM2(J)) / 60.
 40   CONTINUE
      DO 50 J=2,NOBS
        IF (X(1,J) .GT. X(1,1)) THEN
          X(1,J) = X(1,J) - X(1,1)
         ELSE
          X(1,J) = 24. - X(1,1) + X(1,J)
        END IF
 50   CONTINUE
      IF (DAYBEG .GT. X(1,1)) THEN
        DAYBEG = DAYBEG - X(1,1)
       ELSE
        DAYBEG = 24. - X(1,1) + DAYBEG
      END IF
      IF (DAYEND .GT. X(1,1)) THEN
        DAYEND = DAYEND - X(1,1)
       ELSE
        DAYEND = 24. - X(1,1) + DAYEND
      END IF
      X(1,1) = 0.
      WRITE (IOUT,2080)
      WRITE(IOUT,2020) NAME2
      WRITE(IOUT,2045) DIFC,K2,SALIN,DEPTH,IDAY1,IDAY2,INIGH1,INIGH2,BP,
     #  UNITS,Q,AREA,TT,VELO,NOBS
      WRITE (IOUT,2050)
      IF(SALIN .GT. 0.) THEN
        DO 60 J=1,NOBS
          X(4,J) = SALIN
 60     CONTINUE
      END IF
      IF(TEST2 .EQ.0 )CALL COND(N20,NOBS,X)
      DO 70 J=1,NOBS
        WRITE(IOUT,2060) ITM1(J),ITM2(J),(X(I,J),I=2,4)
 70   CONTINUE
      JJ=1
      CALL INTERP(X,NOBS,XNEW1)
C
C      Begin calculating second station at time t + tt
      CALL OXYGEN(I2,DIFC,BP,METD,XNEW1)
      DO 80 I=1,I2
        C2 = (XNEW(7,I) + XNEW1(7,I)) / 2.
        C2 = (C2 / 100.) - 1.0
        C2 = C2 * ADIFC * .25
C
C       Adjust value to a  15 min rate of change / 4 * tt
C       TROC represents differential between downstream oxygen
C       and upstream oxygen (downstream minus upstream).
        TROC=(XNEW1(3,I)-XNEW(3,I))/(TT*4.)
        DLC(I)=TROC+C2
 80   CONTINUE
      NN1=NN+1
      IF (IPRNT .GT. 0) THEN
        WRITE(IOUT,2090)
        CALL PRNT(2)
      END IF
      CALL SUMMER (IDAY,INIGHT)
      RETURN
      END
C
C
C
      SUBROUTINE   INTERP
     I                   (X,NOBS,
     O                    XNEW)
C
C     + + + PURPOSE + + +
C
C     This routine interpolates between input values of temperature,
C     dissolved oxygen, and salinity to obtain values at 15-minute
C     intervals.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER NOBS
      REAL X(7,97), XNEW(7,97)
C
C     + + + ARGUMENT DEFINITIONS + + +
C
C     NOBS   - number of rows of values in X array
C     X      - Input array [contains vakues in the first NOBS rows]
C     XNEW   - Output array including interpolated values
C                     [contains exactly 97 rows]
C
C     + + + LOCAL VARIABLES + + +

      INTEGER I, I1, INC, J, JJ, K
      REAL DIFF(5), DIFFT, XK, XX
C
C     + + + END SPECIFICATIONS + + +
C
      DO 10 I=1,4
        XNEW(I,1) = X(I,1)
 10   CONTINUE
      K = 2
      DO 100 I=2,NOBS
        I1=I-1
C
C       Get the interval between the times of this observation and the
C       last one. If the interval is negative we've passed midnight;
C       correct it by adding 24.0. Then compute INC [the number of 0.25-hour
C       time steps in the interval] as the time interval * 4.0
        DIFFT = X(1,I) - X(1,I1)
        IF (DIFFT .LT. 0.0) DIFFT = DIFFT + 24.0
        INC = DIFFT * 4.0
C
C       Now compute the rate of change in the other values as the
C       difference between the previous values and the current ones
C       divided by the number of time steps in the interval.
        DO 20 J=2,4
          DIFF(J) = (X(J,I) - X(J,I1)) / INC
 20     CONTINUE
C
C       Finally, calculate INC values of each column of XNEW as the
C       previous value plus the incremental difference. Use a fixed value
C       of 0.25 for column 1 [time] and check and correct for passing
C       midnight.
        DO 40 JJ=1,INC
          XNEW(1,K) = XNEW(1,K-1) + 0.25
          IF (XNEW(1,K) .GT. 24.0) XNEW(1,K) = XNEW(1,K) - 24.0
          DO 30 J=2,4
            XNEW(J,K) = XNEW(J,K-1) + DIFF(J)
 30       CONTINUE
          K = K + 1
 40     CONTINUE
C        End of interpolation loop.
 100  CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE   OXYGEN
     I                   (I2,DIFC,BP,METD,
     M                    XNEW)
C
C     + + + PURPOSE + + +
C     Subroutine OXYGEN calculates oxygen solubility and corrects each
C     data value for atmospheric diffusion.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER I2, METD
      REAL XNEW(7,97), DIFC, BP
C
C     + + + ARGUMENT DEFINITIONS + + +
C
C     I2     - number of rows in array XNEW(col,row)
C     DIFC   - atmospheric diffusion coefficient
C     BP     - barometric pressure
C     METD   - problem type [1, 2, or 3]
C     XNEW   - two-dimensional array containing input,
C                     interpolated, and calculated data values.
C
C     + + + LOCAL VARIABLES + + +
      INTEGER I, I1
      REAL AVG, AVG1, CSUBS, DIV, OSC, PSAT, T, S, TA
C
C     + + + INTRINSICS+ + +
      INTRINSIC ALOG, EXP
C
C     + + + END SPECIFICATIONS + + +
C
      DO 20 I=2,I2
        I1=I-1
C       Calculate mean salinity and temperature
        IF(METD .EQ. 2) THEN
          S = XNEW(4,I)
          T = XNEW(2,I)
         ELSE
          S = (XNEW(4,I) + XNEW(4,I1)) / 2.
          T = (XNEW(2,I) + XNEW(2,I1)) / 2.
        END IF
C       Change celsius temperature to absolute
        TA = T + 273.0
C       Calculate oxygen solubility
        OSC = -173.4292 + 249.6339 * (100.0/TA) + 143.3483 *
     #    ALOG(TA / 100.) - 21.8492 * (TA / 100.) + S *
     #    (-0.033096 + 0.014259 * (TA / 100.) - .0017 *
     #    (TA / 100.) ** 2)
        IF (BP .LT. 50.0) THEN
C         Barometric pressure is in inches of mercury
          DIV = 29.92
         ELSE
C         Barometric pressure is in millemeters of mercury
          DIV = 760.
        END IF
C       Adjust log normal saturation value in ML/L to MG/L.
        CSUBS = EXP(OSC) * 1.428 * (BP / DIV)
        PSAT = XNEW(3,I) / CSUBS
C       calculate mean oxygen saturation
        IF (METD .NE. 2) THEN
          AVG1 = (XNEW(3,I) + XNEW(3,I1)) / 2.
          XNEW(7,I) = AVG1 / CSUBS
         ELSE
          XNEW(7,I) = PSAT
          IF (I.EQ.2) XNEW(7,1) = XNEW(7,2)
        END IF
C       Calculate rate of change of oxygen (corrected for diffusion).
        AVG = (XNEW(7,I) + XNEW(7,I1)) / 2.
        XNEW(6,I) = XNEW(3,I) - XNEW(3,I1) + .25 * DIFC * (AVG - 1.00)
 20   CONTINUE
C       Calculate oxygen saturation as percent for output
      DO 30 I=1,97
        XNEW(7,I) = 100. * XNEW(7,I)
 30   CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE   PRNT
     I                 (II)
C
C     + + + PURPOSE + + +
C
C     Prints interpolated and calculated values
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER II
C
C     + + + ARGUMENT DEFINITIONS + + +
C
C     II     - Flag to indicate station in two-station problem
C              [1 = upstream, 2 = downstream]
C
C     + + + COMMON BLOCKS + + +
C
      INCLUDE 'cj3302.inc'
      INCLUDE 'cj3303.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER I, IPRT, J
C
C     + + + LOCAL DEFINITIONS + + +
C
C     IPRT - line counter to control pagination
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT (/' Cumulative  Temperature  Oxygen  Salinity   ',
     #  'Percent' / '  time,hrs    degrees C    MG/L     ',
     #  'ppt     saturation  p-r, MG/L'/)
 2010 FORMAT (/' Cumulative  Temperature  Oxygen  Salinity   ',
     #  'Percent' / '  time,hrs    degrees C    MG/L     ',
     #  'ppt     saturation  p-r, MG/L  Delta C'/)
 2020 FORMAT (3X,F5.2,7X,F6.2,2X,2F10.3,2F11.3)
 2030 FORMAT (3X,F5.2,7X,F6.2,2X,2F10.3,3F11.3)
 2040 FORMAT ('')
C
C     + + + END SPECIFICATIONS + + +
C
      IPRT = 0
      IF (METD .EQ. 1 .OR. II .EQ. 1) THEN
        WRITE (IOUT,2000)
       ELSE
        WRITE (IOUT,2010)
      END IF
      DO 10 I=1,I2
        IF (METD .EQ. 1 .OR. II .EQ. 1) THEN
          WRITE (IOUT,2020)  (XNEW(J,I),J=1,4),XNEW(7,I),XNEW(6,I)
         ELSE
          WRITE (IOUT,2030)  (XNEW1(J,I),J=1,4),XNEW1(7,I),
     #      XNEW1(6,I),DLC(I)
        END IF
        IPRT=IPRT+1
        IF (IPRT .EQ. 45)THEN
          WRITE (IOUT,2040)
          IPRT = 0
          IF(METD .EQ. 1 .OR. II .EQ. 1) THEN
            WRITE (IOUT,2000)
           ELSE
            WRITE (IOUT,2010)
          END IF
        END IF
 10   CONTINUE
      RETURN
      END
C
C
C
      SUBROUTINE   CONS
     I                  (BP,DEPTH,
     M                   K2,
     I                   VELO,XNEW,
     O                   DIFC)
C
C     + + + PURPOSE + + +
C     CONS calculates an atmospheric diffusion coefficient for streams
C     from depth, temperature, barometric pressure, and velocity. The
C     algorithm is from Bennet and Rathbun, 1972 [Professional Paper 737].
C
C     + + + DUMMY ARGUMENTS + + +
      REAL BP, DEPTH, VELO, DIFC, XNEW(7,97)
C
C     + + + ARGUMENT DEFINITIONS + + +
C     BP     - Barometric presure at the station.
C     DEPTH  - Stream depth at the station.
C     K2     - Reaeration coefficient, per day at 
C              20 degrees celsius (base e)
C     VELO   - Stream velocity at the station.
C     XNEW   - Array of interpolated data values; XNEW(2,*)
C                    is temperature.
C     DIFC   - Diffusion coefficient [calculated by the subroutine].
C
C     + + + LOCAL VARIABLES + + +
      INTEGER J
      REAL AVGT,DIV,DTEMP,K2
C
C     + + + END SPECIFICATIONS + + +
C
      AVGT = 0.0
      DO 10 J=1,97
        AVGT = AVGT + XNEW(2,J)
 10   CONTINUE
      AVGT = AVGT / 97.
C     If no value for K2 was furnished by the user, calculate K2 here
C     from depth and velocity
      IF (K2 .LE. 0.0) THEN
        K2 = 8.76 * VELO ** 0.607 / DEPTH ** 1.689
        K2 = K2 * 2.303
      END IF
      IF (BP .LT. 50.0) THEN
C       Barometric pressure is in inches of mercury
        DIV = 29.92
       ELSE
C       Barometric pressure is in millimeters of mercury
        DIV = 760.
      END IF
      DIFC = K2 * 9.07 / 24. * (BP / DIV)
C     Correct K2 to field temp
      DTEMP = AVGT - 20.
      DIFC = DIFC * 1.0241 ** DTEMP
      RETURN
      END
C
C
C
      SUBROUTINE   SUMMER
     I                   (IDAY,INIGHT)
C
C     + + + PURPOSE + + +
C
C     This routine calculates oxygen production and respiration on an
C     areal basis and converts these values to carbon fixation. Net daily
C     production is calculated as the difference between daytime
C     production and night respiration and the p/r ratio is calculated.
C     Results of the computations are output.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER IDAY, INIGHT
C
C     + + + ARGUMENT DEFINITIONS
C
C     IDAY   - The number of the row in array XNEW whose time
C              corresponds to sunrise
C     INIGHT - The number of the row in array XNEW whose
C              time corresponds to sunset
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'cj3301.inc'
      INCLUDE 'cj3302.inc'
      INCLUDE 'cj3303.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER I,J
      REAL CMET, CMET1, DBEG, DEND, DN, P, R
C
C     + + + INTRINSICS + + +
      INTRINSIC ABS
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT (//////32X,'Oxygen Metabolism')
 2010 FORMAT (/13X,'Station number ',A2,':  ', A28)
 2020 FORMAT (/11X,'Net daytime prod.',F9.3,' GM O2/M3/DAY',F9.3,
     #  ' GM C /M3/DAY'/28X,F9.3,' GM O2/M2/DAY',F9.3,
     #  ' GM C /M2/DAY')
 2030 FORMAT (/11X,'Night respiration',F9.3,' GM O2/M3/DAY',F9.3,
     #  ' GM C /M3/DAY'/28X,F9.3,' GM O2/M2/DAY',F9.3,
     #  ' GM C /M2/DAY')
 2040 FORMAT (/11X,' Production during time period ',2I2.2,
     #  ' to ',2I2.2,2X,'hours')
 2050 FORMAT (/11X,'Estimated gross production =',F9.3,
     #  ' GM O2/M3/DAY'/
     #  11X,'Estimated gross respiration =',F8.3,
     #  ' GM O2/M3/DAY')
 2060 FORMAT (/35X,'Area',5X,F8.1)
 2070 FORMAT (/11X,'24 hour community metabolism = ',F9.3,
     #  ' GM O2/M3/DAY'/42X,F9.3,' GM O2/M2/DAY')
 2080 FORMAT (11X,'(Difference between net daily production ',
     #  'and night respiration)')
C
C     + + + END SPECIFICATIONS + + +
C
C     Housekeeping -- zero the array SUM
      DO 10 J=1,4
        DO 10 I=1,2
        SUM(J,I)=0.0
 10   CONTINUE
      IF(METD .EQ. 2) DLC(1) = DLC(2)
      XNEW(6,1) = XNEW(6,2)
      XNEW(7,1) = XNEW(7,2)
      DO 20 I=2,I2
        J = I - 1
C       Day changes are production, night changes respiration.
C       However, depending on what time of day we take the first
C       sample, sunrise [IDAY] may be either before or after
C       sunset [INIGHT] in the XNEW array. We have to take this
C       into account when deciding whether it's night or day
        IF (IDAY .GT. INIGHT) THEN
C         The first sample was taken after sunrise
          IF (I .LE. INIGHT .OR. I .GT. IDAY) THEN
C         Daytime -- oxygen production
            IF(METD .EQ. 2) THEN
              SUM(1,1) = SUM(1,1) + (DLC(J) + .5 * (DLC(I) - DLC(J)))
             ELSE
              SUM(1,1) = SUM(1,1) + (XNEW(6,J) + .5 * (XNEW(6,I)
     #          - XNEW(6,J)))
            END IF
           ELSE
C         Night -- respiration
            IF(METD .EQ. 2) THEN
              SUM(1,2) = SUM(1,2) + (DLC(J) + .5 * (DLC(I) - DLC(J)))
             ELSE
              SUM(1,2) = SUM(1,2) + (XNEW(6,J) + .5 * (XNEW(6,I)
     #          - XNEW(6,J)))
            END IF
          END IF
         ELSE
C         First sample was collected before sunrise (or after sunset)
          IF (I .GT. IDAY .AND. I .LE. INIGHT) THEN
C         Daytime -- oxygen production
            IF(METD .EQ. 2) THEN
              SUM(1,1) = SUM(1,1) + (DLC(J) + .5 * (DLC(I) - DLC(J)))
             ELSE
              SUM(1,1) = SUM(1,1) + (XNEW(6,J) + .5 * (XNEW(6,I)
     #          - XNEW(6,J)))
            END IF
           ELSE
C         Night -- respiration
            IF(METD .EQ. 2) THEN
              SUM(1,2) = SUM(1,2) + (DLC(J) + .5 * (DLC(I) - DLC(J)))
             ELSE
              SUM(1,2) = SUM(1,2) + (XNEW(6,J) + .5 * (XNEW(6,I)
     #          - XNEW(6,J)))
            END IF
          END IF
        END IF
 20   CONTINUE
C     Get oxygen values in terms of grams per metre squared, and per
C     m3, also convert to grams of carbon per m2 and per m3.
C     Assumes photosynthetic quotient=1.2 (Vollenweider, 1969)
      DO 30 I=1,2
        SUM(2,I) = SUM(1,I) * .312
        IF(METD .EQ. 2) THEN
C       Areal productivity for 2 station method calculated using total
C       discharge through the reach during daylight hours
          SUM(3,1) = SUM(1,1) * ((Q * 3600. * HRSUN) / AREA)
          SUM(4,1) = SUM(2,1) * ((Q * 3600. * HRSUN) / AREA)
          SUM(3,2) = SUM(1,2) * ((Q * 3600. * HRDARK) / AREA)
          SUM(4,2) = SUM(2,2) * ((Q * 3600. * HRDARK) / AREA)
         ELSE
C         for one-station method, just multiply grams per m2 by depth
C         note:  conversion factor corrected re CGCrawford, 07/95, kmf.
C         SUM(3,I) = SUM(1,I) * (DEPTH / 3.048)
C         SUM(4,I) = SUM(2,I) * (DEPTH / 3.048)
          SUM(3,I) = SUM(1,I) * (DEPTH / 3.2808)
          SUM(4,I) = SUM(2,I) * (DEPTH / 3.2808)
        END IF
 30   CONTINUE
C     Calculate 24-hour community metabolism (CMET and CMET1) and
C     estimate average daily production (P) and respiration (R).
C
C     Calculation of P and R were added by Claud Baker, August 1991;
C     the equations were furnished by Jon Nowlin, October 1984.
      CMET1 = SUM(3,1) + SUM(3,2)
      CMET = SUM(1,1) + SUM(1,2)
      DBEG = IDAY
      DEND = INIGHT
      DN = ABS(DEND - DBEG) / 96.0
      R = SUM(1,2) / DN
      P = SUM(1,1) - SUM(1,2) + R
      IF(METD .NE. 3) THEN
C     Identify the source of production, and print values
        WRITE (IOUT,2000)
        WRITE (IOUT,2010) '01',NAME1
        IF(METD .EQ. 2) WRITE (IOUT,2010) '02',NAME2
        WRITE (IOUT,2020) (SUM(I,1),I=1,4)
        WRITE (IOUT,2030) (SUM(I,2),I=1,4)
        WRITE (IOUT,2040) IDAY1,IDAY2,INIGH1,INIGH2
        IF(METD .EQ. 2) THEN
          WRITE (IOUT,2060) AREA
         ELSE
        END IF
C
        WRITE (IOUT,2070) CMET,CMET1
        WRITE (IOUT,2080)
        WRITE (IOUT,2050) P,R
      END IF
C
      RETURN
      END
C
C
C
      SUBROUTINE   BELLA
     I                  (IDAY,INIGHT)
C
C     + + + PURPOSE + + +
C
C     BELLA calculates lake production and metabolism. It's operation
C     is similar to that of ODUM1 and ODUM2 but divides the lake into
C     discrete horizontal "slices". Atmospheric reaeration is applied
C     only on the uppermost slice; user-defined dispersion coefficients
C     determine oxygen transfer between layers.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER IDAY, INIGHT
C
C     + + + ARGUMENT DEFINITIONS + + +
C
C     IDAY   - element of the data arrays that corresponds to sunrise
C     INIGHT - element of the data arrays that corresponds to sunset
C
C     + + + COMMON BLOCKS + + +
      INCLUDE 'cj3302.inc'
      INCLUDE 'cj3303.inc'
      INCLUDE 'cj3304.inc'
C
C     + + + LOCAL VARIABLES + + +
      INTEGER I, J, JJ, JK, K, K2, KK, IPRT
      REAL COM, DEP, DSTM(97), PNET1(10), PNET2(10), PR1, PR11, PR2
      REAL PR3, PRAT, RESP1(10), RESP2(10), SPNET1, SPNET2
      REAL SRESP1, SRESP2, SUMPR(97)
      CHARACTER*10 HEADER(11,4), CHANGE(11,97)
C
C     + + + LOCAL DEFINITIONS + + +
C     HEADER - Array to hold headings for the diffusion-corrected
C              rate of change table
C     CHANGE - Array to hold values for the diffusion-corrected
C              rate of change table
C
C     + + + EXTERNALS + + +
      EXTERNAL  SUMMER
C
C     + + + DATA INITIALIZATIONS + + +
      DATA HEADER /44*'          '/, CHANGE /1067*'          '/
C
C     + + + OUTPUT FORMATS + + +
 2000 FORMAT(22X,' Diffusion corrected rate of change'/)
 2002 FORMAT(6(3X,A))
 2004 FORMAT(A)
 2005 FORMAT(F8.2)
 2006 FORMAT(A,I3)
 2007 FORMAT(F7.1,A)
 2008 FORMAT(F8.3)
 2010 FORMAT(//////5X,'Station',3X,A28//)
 2020 FORMAT(' Summary of lake, bay, or pond oxygen metabolism',
     #  ' computations using Bella method'//20X,
     #  'Net production(daylight hours)          Night  respiration'//,
     #  1X,'Slice no  Depth,M   GM O2/M3/DAY       GM C/M3/DAY',5X,
     #  'GM O2/M3/DAY   GM C/M3/DAY'/)
 2030 FORMAT(I6,6X,F5.1,7X,F7.3,11X,F7.3,10X,F7.3,7X,F7.3)
 2040 FORMAT(/3X,'Sum',18X,F7.3,11X,F7.3,10X,F7.3,7X,F7.3)
 2050 FORMAT(/' Total for water col.',F10.3,11X,F7.3,8X,
     #  F9.3,5X,F9.3)
 2060 FORMAT(/5X,'24 hour community metabolism ',
     #  '(difference between net daily production'/11X,
     #  ' and night respiration) =',F8.3,2X,'GM 02/M2/DAY'//10X,
     #  'P/R ratio =',F9.3,///,10X,'NOTE:',5X,
     #  'Multiply individual table values by slice interval ',/20X,
     #  'to get total production and respiration for each slice.')
 2070 FORMAT ('')
C
C     + + + END SPECIFICATIONS + + +
C
C     Initialize array DSTM
      DSTM(1) = 0.0
      DO 10 J=2,97
        JK = J - 1
        DSTM(J) = DSTM(JK) + 0.25
 10   CONTINUE
C     find sunrise and sunset in first slice
      DO 20 I=2,NN
        DV(I) = DV(I) * 900.
 20   CONTINUE
      DO 30 I=1,I2
        XNEW(6,I) = 0.0
 30   CONTINUE
C     calculate p-r arrays
      DELTZ=DELTZ*100.
      DO 50 K=1,NN
        DO 40 J=2,I2
          JK = J - 1
          PR1 = (XBELLA(J,K) - XBELLA(JK,K))
          KK = K + 1
          K2 = K - 1
C         PR11 is the surface diffusion coef multiplier for K=1; also the
C         dispersion coef multiplier for K NE 1 and NE NN
          IF(K .NE. 1) THEN
            PR11 = DV(K) / DELTZ ** 2
           ELSE
            PR11 = 0.25 * DV(1) * FUNC(J)
          END IF
C         Calculations for internal dispersion above
          IF(K .EQ. 1) THEN
            PR2 = PR1 + PR11
           ELSE
            PR2 = PR1 + PR11 * (XBELLA(J,K2) - XBELLA(J,K))
          END IF
C         Calculations for internal dispersion
          IF(K .EQ. NN) THEN
            PR3 = PR2
           ELSE
            PR3 = PR2 + (DV(KK) / DELTZ ** 2) * (XBELLA(J,KK) -
     #        XBELLA(J,K))
          END IF
          XNEW(6,J) = PR3
 40     CONTINUE
        XNEW(6,1) = XNEW(6,2)
        DEP = K * DELTZ / 100.
        IF(IPRNT.GT.0) THEN
C
C         write appropriate values to the HEADER and CHANGE arrays
C         for printing the diffusion corrected rate of change table
          IF(K .EQ. 1) THEN
C
C           write cumulative time to the first column of the arrays
            WRITE (HEADER(1,3),2004) 'Cumulative'
            WRITE (HEADER(1,4),2004) 'Time,Hours'
            DO 42 J=1,I2
              WRITE (CHANGE(1,J),2005) DSTM(J)
 42         CONTINUE
          END IF
          WRITE (HEADER(K+1,1),2004) 'Lake slice'
          WRITE (HEADER(K+1,2),2006) 'number',K
          WRITE (HEADER(K+1,3),2004) ' (depth'
          WRITE (HEADER(K+1,4),2007) DEP,' M)'
          DO 45 J=1,I2
            WRITE (CHANGE(K+1,J),2008) XNEW(6,J)
 45       CONTINUE
        END IF
        CALL SUMMER (IDAY,INIGHT)
        PNET1(K) = SUM(1,1)
        PNET2(K) = SUM(2,1)
        RESP1(K) = SUM(1,2)
        RESP2(K) = SUM(2,2)
 50   CONTINUE
      WRITE (IOUT,2070)
      WRITE (IOUT,2000)
      WRITE (IOUT,2002) ((HEADER(I,KK),I=1,6),KK=1,4)
      WRITE (IOUT,2004) ' '
      IPRT = 0
      DO 55 J=1,I2
        WRITE (IOUT,2002) (CHANGE(I,J),I=1,6)
        IPRT = IPRT + 1
        IF (IPRT .EQ. 45) THEN
          IPRT = 0
          WRITE (IOUT,2070)
          WRITE (IOUT,2002) ((HEADER(I,KK),I=1,6),KK=1,4)
          WRITE (IOUT,2004) ' '
        END IF
 55   CONTINUE
      WRITE(IOUT,2010) NAME1
      WRITE(IOUT,2020)
      DO 60 K=1,NN
        DEP = K * DELTZ / 100.
        WRITE(IOUT,2030)K,DEP,PNET1(K),PNET2(K),RESP1(K),RESP2(K)
  60  CONTINUE
      SPNET1 = 0.0
      SPNET2 = 0.0
      SRESP1 = 0.0
      SRESP2 = 0.0
      DO 70 J=1,NN
        SPNET1 = SPNET1 + PNET1(J)
        SPNET2 = SPNET2 + PNET2(J)
        SRESP1 = SRESP1 + RESP1(J)
        SRESP2 = SRESP2 + RESP2(J)
 70   CONTINUE
      PRAT = -SPNET1 / SRESP1
      WRITE(IOUT,2040)SPNET1,SPNET2,SRESP1,SRESP2
      SPNET1 = SPNET1 * DELTZ / 100.
      SPNET2 = SPNET2 * DELTZ / 100.
      SRESP1 = SRESP1 * DELTZ / 100.
      SRESP2 = SRESP2 * DELTZ / 100.
      COM = SPNET1 + SRESP1
      WRITE(IOUT,2050)SPNET1,SPNET2,SRESP1,SRESP2
      WRITE(IOUT,2060)COM,PRAT
C
      RETURN
      END
C
C
C
      SUBROUTINE   OPENFS
     I                    (IREAD,IOUT,
     O                     IRET)
C
C     + + + PURPOSE + + +
C
C     This subroutine queries the user for file names and opens the files.
C     It returns 0 if successful.
C
C     + + + DUMMY ARGUMENTS + + +
      INTEGER IREAD, IOUT, IRET
C
C     + + + ARGUMENT DEFINITIONS + + +
C
C     IREAD  - FORTRAN file unit for input
C     IOUT   - FORTRAN file unit for output
C     IRET   - Returned value; 0 if successful
C
C     + + + LOCAL VARIABLES + + +
      INTEGER IERR, RETRY
      CHARACTER*64 FILNAM
      CHARACTER*1 ANSWER
C
C     + + + END SPECIFICATIONS + + +
C
10    CONTINUE
        WRITE (*,*) 'Enter the name of the input file'
        READ (*,'(A)') FILNAM
        OPEN (UNIT=IREAD,FILE=FILNAM,STATUS='OLD',IOSTAT=IERR,
     #    ERR=20)
C       input file opened successfully; open output file
        WRITE (*,*) 'Enter the name of the output file'
        READ (*,'(A)') FILNAM
        OPEN (UNIT=IOUT,FILE=FILNAM)
C       turn off re-try flag and set return code to 0
        RETRY = 0
        IRET = 0
        GO TO 30
 20     CONTINUE
C       error opening input file
        WRITE (*,*) 'File ',FILNAM, 'not found.'
        WRITE (*,*) ' Do you want to re-enter the file name (y or n)'
        READ (*,'(A)') ANSWER
        IF (ANSWER .EQ. 'y' .OR. ANSWER .EQ. 'Y') THEN
C         Turn on re-try flag and try again to open input file
          RETRY = 1
          IRET = IERR
         ELSE
C         Turn off re-try flag and set error code
          RETRY = 0
          IRET = IERR
        END IF
30      CONTINUE
      IF (RETRY .EQ. 1) GO TO 10
      RETURN
      END
